ChainResult<R> class

A monad that wraps the result of ResponsibilityChain handler node execution.

The type R is the type contained in the result.

The value getter should not be used without checking if the result is successful using the isSuccessful property.

Constructors

ChainResult.failure()
Creates an unsuccessful ChainResult without the value.
ChainResult.success(R value)
Creates a successful ChainResult with the value value.

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuccessful bool
Returns true if the result contains the exact result value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → R
Returns the value of the result, if the result is successful.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited